# Changelog

## Next

### 0.2.0

- Feature: Updated to Python 3.

### 0.1.2

- Bugfix: Readme markdown fix for pypi.

## 0.1.1

- Bugfix: Dependency fix for pypi.

## 0.1.0

- Cleanup: Removed fullscreen mode.
- Refactor: Rewrote terminal into class.
- Refactor: Rewrote stage and theme into classes.
- Feature: Updated package manager.
